require "button"
require "player"
require "weapon"
require "enemy"
require "background"
require "sound"
require "powerup"

function love.load()
	gamestate = "menu"

	--SOUND
	menuMusic = TEsound.playLooping('music/Castlevania (NES) Music - Stage 13 Heart of Fire.mp3', 4 * 1024 * 1024)

	--VITAL VARIABLES
	backgroundPic = love.graphics.newImage("images/bg.png")
	directionsPic = love.graphics.newImage("images/directions.png")
	love.graphics.setBackgroundColor(0,0,0)
	screenWidth = love.graphics.getWidth()
	screenHeight = love.graphics.getHeight()
	stat_font = love.graphics.newFont("fonts/Action Comics Black.ttf",15)
	die_font = love.graphics.newFont("fonts/dfdChasquilla.otf",50)
	button_font = love.graphics.newFont("fonts/Action Comics Black.ttf",18)
	title_font = love.graphics.newFont("fonts/Action Comics Black.ttf",20)
	directions_font = love.graphics.newFont("fonts/Action Comics Black.ttf",12)

	--BUTTONS
	button.spawn(5,screenHeight / 4,"CONTINUE...", "play")
	button.spawn(5,screenHeight / 2,"QUIT", "quit")
	button.spawn(5,screenHeight / 3,"NEW GAME...", "restart")

	--LOADING LIBRARIES
    background.load()
    player.load()
    weapon.load()
    enemy.load()
    powerup.load()

	--HIGHSCORE LOAD
	local scores = love.filesystem.load("scores.lua")

	if scores then
		scores()
	end
end
--
function love.mousepressed(x,y)
	if gamestate == "menu" then
		button.click(x,y)
	end
end
--
function love.keypressed(key)
	if gamestate == "menu" then
		if key == "escape" then
			love.quit()
		end
	end

	if gamestate == "playing" then
		player.shoot(key)
		if key == "escape" then
			gamestate = "menu"
		end
	end
end
--
function love.draw()
	if gamestate == "menu" then
		love.graphics.setColor(255,255,255)
		love.graphics.draw(backgroundPic,0,0)
		love.graphics.draw(directionsPic,375,480)
		love.graphics.setFont(directions_font)
		love.graphics.setColor(255,0,0)
		love.graphics.print("SHOOT - SPACEBAR",350 - directions_font:getWidth("SHOOT - SPACEBAR"),520)
		love.graphics.setFont(title_font)
		love.graphics.print("SPACE SHOOT UP",screenWidth - title_font:getWidth("SPACE SHOOT UP") - 10,10)

		button.draw()
	end
	--
	if gamestate == "playing" then
		DRAW_BACKGROUND()
		DRAW_PLAYER()
		DRAW_WEAPON()
		DRAW_ENEMY()
		DRAW_POWERUP()

		love.graphics.setFont(stat_font)
		love.graphics.setColor(255,0,0)
    	love.graphics.print("HEALTH",0,0)
    	love.graphics.print("POINTS",screenWidth - stat_font:getWidth("POINTS"),0)
    	love.graphics.print("LEVEL",screenWidth - stat_font:getWidth("LEVEL"), stat_font:getHeight() * 2)
    	love.graphics.print("H-SCORE",0,stat_font:getHeight() * 2)
    	love.graphics.print("CANON   ",0,screenHeight - stat_font:getHeight())

    	love.graphics.print(player.health,0, stat_font:getHeight())
    	love.graphics.print(player.points, screenWidth - stat_font:getWidth(player.points), stat_font:getHeight())
    	love.graphics.print(player.level, screenWidth - stat_font:getWidth(player.level), stat_font:getHeight() * 3)
    	love.graphics.print(player.highscore, 0, stat_font:getHeight() * 3)
    	love.graphics.print(canon.round, stat_font:getWidth("CANON   "), screenHeight - stat_font:getHeight())

    	love.graphics.print("ESC - MENU",screenWidth - stat_font:getWidth("ESC - MENU"),screenHeight - stat_font:getHeight())

    	--PLAYER LOSE
    	if player.points < 0 then
			love.graphics.setFont(die_font)
			love.graphics.setColor(255,0,0)
			love.graphics.printf("!!!YOU LOSE!!!",0, screenHeight / 2, screenWidth, "center")
		end
		if player.health < 1 then
			love.graphics.setFont(die_font)
			love.graphics.setColor(255,0,0)
			love.graphics.printf("!!!YOU LOSE!!!",0, screenHeight / 2, screenWidth, "center")
		end
    end
end
--
function love.update(dt)
	--SOUND
	TEsound.cleanup()

	--HIGHSCORE SAVE
	if player.points > tonumber(player.highscore) then
		player.highscore = player.points
		love.filesystem.write("scores.lua", "player.highscore\n=\n" .. player.highscore)
	end
	--
	mouseX = love.mouse.getX()
	mouseY = love.mouse.getY()

	if gamestate == "menu" then
		button.check()
	end
	--
	if gamestate == "playing" then
		UPDATE_BACKGROUND(dt)
		UPDATE_PLAYER(dt)
		UPDATE_WEAPON(dt)
		UPDATE_ENEMY(dt)
		UPDATE_POWERUP(dt)
	end
end
--
function restart()
	background.load()
	player.load()
	weapon.load()
	enemy.load()
	powerup.load()
end
--
function love.quit()
	--HIGHSCORE SAVE
	love.filesystem.write("scores.lua", "player.highscore\n=\n" .. player.highscore)
	--
	love.event.quit()
end